@@ -35,13 +35,13 @@ import signal
 import sys
 import unittest
 
-from gi import require_version as gi_require_version
+from gi import require_version as gi_require_version # type: ignore
 gi_require_version('GLib', '2.0')
 gi_require_version('Gdk', '3.0')
 gi_require_version('Gio', '2.0')
 gi_require_version('Gtk', '3.0')
 gi_require_version('IBus', '1.0')
-from gi.repository import GLib
+from gi.repository import GLib # type: ignore
 from gi.repository import Gdk
 from gi.repository import Gio
 from gi.repository import Gtk
@@ -99,6 +99,7 @@ class SimpleGtkTestCase(unittest.TestCase):
             schema='org.freedesktop.ibus.engine.typing-booster')
         cls._orig_dictionary = cls._gsettings.get_string('dictionary')
         cls._orig_tabenable = cls._gsettings.get_boolean('tabenable')
+        cls._orig_inputmode = cls._gsettings.get_boolean('inputmode')
         signums = [getattr(signal, s, None) for s in
                    'SIGINT SIGTERM SIGHUP'.split()]
         for signum in filter(None, signums):
@@ -111,6 +112,7 @@ class SimpleGtkTestCase(unittest.TestCase):
     def tearDownClass(cls):
         cls._gsettings.set_string('dictionary', cls._orig_dictionary)
         cls._gsettings.set_boolean('tabenable', cls._orig_tabenable)
+        cls._gsettings.set_boolean('inputmode', cls._orig_inputmode)
 
     @classmethod
     def signal_handler(cls, user_data):
@@ -132,6 +134,7 @@ class SimpleGtkTestCase(unittest.TestCase):
         self.__reset_coming = False
         self._gsettings.set_string('dictionary', 'fr_FR,en_US')
         self._gsettings.set_boolean('tabenable', False)
+        self._gsettings.set_boolean('inputmode', True)
 
     def register_ibus_engine(self):
         self.__bus = IBus.Bus()
@@ -156,7 +159,7 @@ class SimpleGtkTestCase(unittest.TestCase):
             description='Test Typing Booster Component',
             version='1.0',
             license='GPL',
-            author=('Mike FABIAN <mfabian@redonat.com>, '
+            author=('Mike FABIAN <mfabian@redhat.com>, '
                     + 'Anish Patil <anish.developer@gmail.com>'),
             homepage='http://mike-fabian.github.io/ibus-typing-booster',
             command_line='',
