@@ -24,9 +24,9 @@ This file implements test cases for suggestions from hunspell dictionaries
 import sys
 import unittest
 
-from gi import require_version
+from gi import require_version # type: ignore
 require_version('IBus', '1.0')
-from gi.repository import IBus
+from gi.repository import IBus # type: ignore
 
 sys.path.insert(0, "../engine")
 import hunspell_suggest
@@ -36,18 +36,18 @@ sys.path.pop(0)
 IMPORT_ENCHANT_SUCCESSFUL = False
 IMPORT_HUNSPELL_SUCCESSFUL = False
 try:
-    import enchant
+    import enchant # type: ignore
     IMPORT_ENCHANT_SUCCESSFUL = True
 except (ImportError,):
     try:
-        import hunspell
+        import hunspell # type: ignore
         IMPORT_HUNSPELL_SUCCESSFUL = True
     except (ImportError,):
         pass
 
 IMPORT_LIBVOIKKO_SUCCESSFUL = False
 try:
-    import libvoikko
+    import libvoikko # type: ignore
     IMPORT_LIBVOIKKO_SUCCESSFUL = True
 except (ImportError,):
     pass
@@ -58,6 +58,34 @@ def get_libvoikko_version():
     else:
         return '0'
 
+def enchant_sanity_test(language: str = '', word: str = '') -> bool:
+    '''Checks whether python3-enchant returns some suggestions given a
+    language and a word.
+
+    :param language: The language of the dictionary to try
+    :param word: The word to give to enchant to ask for suggestions
+
+    This is used as a sanity check whether python3-enchant works at all.
+    For example, if a Czech dictionary is opened like
+
+        d = enchant.Dict('cs_CZ')
+
+    and then something like
+
+        retval = d.suggest('Praha')
+
+    returns an empty list instead of a list of some words, then
+    something is seriously wrong with python3-enchant and it is better
+    to skip the test case which relies on python3-enchant working for
+    that language.
+    '''
+    if not (language and word):
+        return False
+    d = enchant.Dict(language)
+    if d.suggest(word):
+        return True
+    return  False
+
 class HunspellSuggestTestCase(unittest.TestCase):
     def setUp(self):
         self.maxDiff = None
@@ -71,6 +99,15 @@ class HunspellSuggestTestCase(unittest.TestCase):
     @unittest.skipUnless(
         IMPORT_ENCHANT_SUCCESSFUL,
         "Skipping because this test requires python3-enchant to work.")
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('cs_CZ')[0],
+        'Skipping because no Czech hunspell dictionary could be found.')
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('de_DE')[0],
+        'Skipping because no German hunspell dictionary could be found.')
+    @unittest.skipUnless(
+        enchant_sanity_test(language='cs_CZ', word='Praha'),
+        'Skipping because python3-enchant seems broken for cs_CZ.')
     def test_de_DE_cs_CZ_enchant(self):
         h = hunspell_suggest.Hunspell(['de_DE', 'cs_CZ'])
         self.assertEqual(
@@ -102,6 +139,12 @@ class HunspellSuggestTestCase(unittest.TestCase):
     @unittest.skipUnless(
         IMPORT_HUNSPELL_SUCCESSFUL and not IMPORT_ENCHANT_SUCCESSFUL,
         "Skipping because this test requires python3-pyhunspell to work.")
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('cs_CZ')[0],
+        'Skipping because no Czech hunspell dictionary could be found.')
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('de_DE')[0],
+        'Skipping because no German hunspell dictionary could be found.')
     def test_de_DE_cs_CZ_pyhunspell(self):
         h = hunspell_suggest.Hunspell(['de_DE', 'cs_CZ'])
         self.assertEqual(
@@ -130,6 +173,9 @@ class HunspellSuggestTestCase(unittest.TestCase):
             h.suggest('filosofičtějš')[0],
             ('filosofic\u030Cte\u030Cjs\u030Ci\u0301', 0))
 
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('it_IT')[0],
+        'Skipping because no Italian hunspell dictionary could be found.')
     def test_it_IT(self):
         h = hunspell_suggest.Hunspell(['it_IT'])
         self.assertEqual(
@@ -140,6 +186,9 @@ class HunspellSuggestTestCase(unittest.TestCase):
              ('principiarti', -1),
              ('principiasti', -1)])
 
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('es_ES')[0],
+        'Skipping because no Spanish hunspell dictionary could be found.')
     def test_es_ES(self):
         h = hunspell_suggest.Hunspell(['es_ES'])
         self.assertEqual(
@@ -155,6 +204,9 @@ class HunspellSuggestTestCase(unittest.TestCase):
             h.suggest('tenéis')[0],
             ('tene\u0301is', 0))
 
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
+        'Skipping because no US English hunspell dictionary could be found.')
     def test_en_US(self):
         h = hunspell_suggest.Hunspell(['en_US'])
         self.assertEqual(
@@ -168,6 +220,9 @@ class HunspellSuggestTestCase(unittest.TestCase):
              ('came l', -1),
              ('camels', -1)])
 
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('fr_FR')[0],
+        'Skipping because no French hunspell dictionary could be found.')
     def test_fr_FR(self):
         h = hunspell_suggest.Hunspell(['fr_FR'])
         self.assertEqual(
@@ -218,6 +273,9 @@ class HunspellSuggestTestCase(unittest.TestCase):
     @unittest.skipUnless(
         IMPORT_ENCHANT_SUCCESSFUL,
         "Skipping because this test requires python3-enchant to work.")
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
+        'Skipping because no US English hunspell dictionary could be found.')
     def test_en_US_spellcheck_enchant(self):
         d = hunspell_suggest.Dictionary('en_US')
         self.assertEqual(d.spellcheck_enchant('winter'), True)
@@ -226,6 +284,9 @@ class HunspellSuggestTestCase(unittest.TestCase):
     @unittest.skipUnless(
         IMPORT_ENCHANT_SUCCESSFUL,
         "Skipping because this test requires python3-enchant to work.")
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
+        'Skipping because no US English hunspell dictionary could be found.')
     def test_en_US_spellcheck_suggest_enchant(self):
         d = hunspell_suggest.Dictionary('en_US')
         self.assertEqual(
@@ -235,6 +296,9 @@ class HunspellSuggestTestCase(unittest.TestCase):
     @unittest.skipUnless(
         IMPORT_HUNSPELL_SUCCESSFUL and not IMPORT_ENCHANT_SUCCESSFUL,
         "Skipping because this test requires python3-pyhunspell to work.")
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
+        'Skipping because no US English hunspell dictionary could be found.')
     def test_en_US_spellcheck_pyhunspell(self):
         d = hunspell_suggest.Dictionary('en_US')
         self.assertEqual(d.spellcheck_pyhunspell('winter'), True)
@@ -243,6 +307,9 @@ class HunspellSuggestTestCase(unittest.TestCase):
     @unittest.skipUnless(
         IMPORT_HUNSPELL_SUCCESSFUL and not IMPORT_ENCHANT_SUCCESSFUL,
         "Skipping because this test requires python3-pyhunspell to work.")
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
+        'Skipping because no US English hunspell dictionary could be found.')
     def test_en_US_spellcheck_suggest_pyhunspell(self):
         d = hunspell_suggest.Dictionary('en_US')
         self.assertEqual(
